
import setuptools

setuptools.setup(
	name = "seepeeyou",
	version = "1",
	author = "Enric Meinhardt-Llopis",
	author_email = "enric.meinhardt@fastmail.com",
	description = "The Definitive Interface for Image Processing Practitioners",
	url = "https://github.com/mnhrdt/imscript",
	classifiers = [
		"Operating System :: OS Independent",
		"License :: OSI Approved :: GNU Affero General Public License v3",
		"Topic :: Scientific/Engineering :: Image Processing",
		"Topic :: Scientific/Engineering :: Mathematics"
		],
	py_modules = ["cpu"]
)
